---
toc: false
---

# API documentation

## `arvi.timeseries.RV`

::: arvi.timeseries.RV
    handler: python
    options:
        show_bases: false
        show_root_heading: false
        show_source: false
        merge_init_into_class: false
        group_by_category: true
        show_category_heading: true


## Sub-packages

The following are mostly internal packages and functions with which a user may
not need to interact directly.

??? example "`arvi.simbad` API"

    ::: arvi.simbad
        handler: python
        options:
            show_root_heading: true
            show_source: false
            merge_init_into_class: true


??? example "`arvi.stats` API"

    ::: arvi.stats
        handler: python
        options:
            show_root_heading: true
            show_source: false
